@@ -34,18 +34,19 @@ class BaseView(Gtk.Stack):
 
     _now_playing_icon_name = 'media-playback-start-symbolic'
     _error_icon_name = 'dialog-error-symbolic'
+
+    selected_items_count = GObject.Property(type=int, default=0, minimum=0)
     selection_mode = GObject.Property(type=bool, default=False)
 
     def __repr__(self):
         return '<BaseView>'
 
     @log
-    def __init__(self, name, title, window, use_sidebar=False, sidebar=None):
+    def __init__(self, name, title, window, sidebar=None):
         """Initialize
         :param name: The view name
         :param title: The view title
         :param GtkWidget window: The main window
-        :param use_sidebar: Whether to use sidebar
         :param sidebar: The sidebar object (Default: Gtk.Box)
         """
 
@@ -72,23 +73,14 @@ class BaseView(Gtk.Stack):
         # Setup the main view
         self._setup_view()
 
-        if use_sidebar:
-            self.stack = Gtk.Stack()
-            dummy = Gtk.Frame(visible=False)
-            self.stack.add_named(dummy, 'dummy')
-            if sidebar:
-                self.stack.add_named(sidebar, 'sidebar')
-            else:
-                self.stack.add_named(self._box, 'sidebar')
-            self.stack.set_visible_child_name('dummy')
-            self._grid.add(self.stack)
-        if not use_sidebar or sidebar:
-            self._grid.add(self._box)
+        if sidebar:
+            self._grid.add(sidebar)
+
+        self._grid.add(self._box)
 
         self._star_handler = StarHandlerWidget(self, 9)
         self._window = window
-        self._header_bar = window.headerbar
-        self._selection_toolbar = window.selection_toolbar
+        self._headerbar = window._headerbar
 
         self.name = name
         self.title = title
@@ -103,13 +95,13 @@ class BaseView(Gtk.Stack):
         grilo.connect('changes-pending', self._on_changes_pending)
 
         self.bind_property(
-            'selection-mode', self._selection_toolbar, 'visible',
-            GObject.BindingFlags.SYNC_CREATE)
-
-        self.bind_property(
-            'selection-mode', self._header_bar, 'selection-mode',
+            'selection-mode', self._window, 'selection-mode',
             GObject.BindingFlags.BIDIRECTIONAL)
 
+        if (grilo.tracker is not None
+                and not self._init):
+            self._on_grilo_ready()
+
     @log
     def _on_changes_pending(self, data=None):
         pass
@@ -121,10 +113,11 @@ class BaseView(Gtk.Stack):
 
     @log
     def _on_grilo_ready(self, data=None):
-        if (self._header_bar.props.stack.props.visible_child == self
+        if (self._headerbar.props.stack.props.visible_child == self
                 and not self._init):
             self._populate()
-        self._header_bar.props.stack.connect(
+
+        self._headerbar.props.stack.connect(
             'notify::visible-child', self._on_headerbar_visible)
 
     @log
@@ -133,12 +126,6 @@ class BaseView(Gtk.Stack):
                 and not self._init):
             self._populate()
 
-    @log
-    def _update_header_from_selection(self, n_items):
-        """Updates header during item selection."""
-        self._selection_toolbar.props.items_selected = n_items
-        self._header_bar.props.items_selected = n_items
-
     @log
     def _populate(self, data=None):
         self.populate()
@@ -179,27 +166,16 @@ class BaseView(Gtk.Stack):
                 self.model[itr][6] = value
                 count += 1
             itr = self.model.iter_next(itr)
+
         return count
 
     @log
     def select_all(self):
         """Select all the available songs."""
-        count = self._set_selection(True)
-
-        self._selection_toolbar.props.items_selected = count
-        self._update_header_from_selection(count)
+        self.props.selected_items_count = self._set_selection(True)
 
     @log
     def unselect_all(self):
         """Unselects all the selected songs."""
         self._set_selection(False)
-        self._selection_toolbar.props.items_selected = 0
-        self._header_bar.props.items_selected = 0
-
-    @log
-    def set_player_visible(self, visible):
-        """Set PlayWidget action visibility
-
-        :param bool visible: Set actionbar visibility
-        """
-        self._window.player_toolbar.set_visible(visible)
+        self.props.selected_items_count = 0
