@@ -116,7 +116,6 @@ class SmoothScale(Gtk.Scale):
         if duration != -1.:
             self.set_range(0.0, duration * 60)
             self.set_increments(300, 600)
-            self._on_state_change(None, None)
 
     @log
     def _on_smooth_scale_seek_finish(self, value):
@@ -176,12 +175,7 @@ class SmoothScale(Gtk.Scale):
         the slider SmoothScale move smoothly based on the current song
         duration and scale length.
         """
-        # Do not run until SmoothScale has been realized and GStreamer
-        # provides a duration.
-        duration = self._player.props.duration
-        if (self.get_realized() is False
-                or duration == -1.):
-            return
+        duration = abs(self._player.props.duration)
 
         # Update self._timeout.
         width = self.get_allocated_width()
@@ -189,7 +183,7 @@ class SmoothScale(Gtk.Scale):
             Gtk.StateFlags.NORMAL)
         width = max(width - (padding.left + padding.right), 1)
 
-        timeout_period = min(1000 * duration // width, 1000)
+        timeout_period = min(1000 * duration // width, 200)
 
         if self._timeout:
             GLib.source_remove(self._timeout)
